# Distributed Computing

::: fdtdx.core.jax.sharding.get_named_sharding_from_shape
::: fdtdx.core.jax.sharding.get_dtype_bytes
::: fdtdx.core.jax.sharding.pretty_print_sharding
::: fdtdx.core.jax.sharding.create_named_sharded_matrix
